---
header-includes:
  - \usepackage[T1]{fontenc}
  - \usepackage[french]{babel}
  - \usepackage{datetime}
  - \usepackage{hyperref}
---

# Semaine 5: Systèmes experts à base de cas

## Raisonnement à partir de cas (Renaud 2007)

### Introduction
- Développés à partir des années 1980 par les travaux de Schank et Kolodner
- Raisonnement par analogie
- Domaines:
    - Aide à la décision 
    - Planification
    - Ordonnancement
    - Aide à la conception
- Décrire le vocabulaire permettant de décrire les cas avec une ontologie
- Laisser les experts donner des exemples de problèmes résolus au lieu de leur demander de décrire leur expertise sous forme abstraite
- Période d'amorçage, puis apprentissage à mesure que de nouveaux cas sont résolus.
- Cas: 
    - représentation d'un épisode de résolution de problèmes
    - Généralement exprimé par un problème et une solution
    - Unité de connaissance et non simplement une donnée
- Type de cas:
    - Leçons apprises
    - Meilleures pratiques d'un métier
    - Histoires symboliques
- Types de problème à résoudre:
    - Planification
        - État initial et but à atteindre
        - Solution: plan permettant de parcourir l'espace d'états
    - Décision
        - Solution: une décision
    - Configuration
    - Diganostic
    - Ordonnancement
- Étapes:
    - Élaboration
    - Remémorisation: sélectionner un cas source
        - Remémorer des cas par appariement
        - Dériver des solutions plausibles
    - Adaptation: raisonnement par analogie. classification = pas besoin de cette étape, peut utiliser une moyenne ou autre mesure sur les K cas voisins
    - Validation
    - Mémorisation
- Similarité: Définie par une mesure de similarité, parfois besoin d'une ontologie pour représenter la connaissance du domaine
- Conception:
    - Acquisition des connaissances
        - Choix d'un mode de représentation
    - Choisir les étapes à implanter
    - Maintenance de la base de cas
- Formalismes:
    - Représentation des connaissances par objets
    - Théorie des sous-ensembles flous
    - Théorie des possibilités
    - Langages de modélisation graphique et textuels
    - Systèmes multi-agents
    - Systèmes neuromimétiques

### Chapitre 4: le système RECRE

- Développé chez [Hydro-Québec](http://www.hydroquebec.com/innovation/fr/pdf/2012G069-RECRE.pdf) pour la remise en charge du réseau.
- Un plan est nécessaire selon les organismes de réglementation
- Difficulté liée au fait que le réseau est grand et la tension très élevée
- Les équipements nécessaires ne sont pas toujours disponibles dépendant de la période de l'année
- Capitaliser le patrimoine de connaissances accumulées avant le départ des experts du domaine

#### Étapes

1. Élaboration:
    - Problème de planification
    - $E_0$ est l'état initial du réseau suite à la panne générale
    - $B$ est la condition qui permet de conclure que le réseau principal est rétabli
1. Remémoration:
    - Dérivation des solutions plausibles
    - Vérifier l'applicabilité
    - Approche similaire au système CREEK
    - Stratégie de résolution de problèmes: RàPC hiérarchique. Éléments de solutions de plusieurs sources
    - Minimise le recours à l'adaptation
1. Adaptation:
    - En l'absence de scénario remémoré ou recomposé, l'adaptation est faite manuellement par des employés. Phase II du projet
1. Mémorisation:
    - Utilisation d'un éditeur de connaissances approprié.

#### Ingénierie des connaissances

Méthode d'ingénierie des connaissances MASK: 6 modèles:

- Concepts
- Activités: action sd'un acteur sur les systèmes selon d'entrées, sorties, ressources et connaissances
- Tâches: Organiser les activités en procédures
- Phénomènes: réactions à des évènements
- Lignées: évolution des connaissances au niveau du contenu
- Historique: évolution des connaissances dans le temps

Intégration des 6 modèles dans une ontologie. Formalisme du projet SATT et de l'outil MDI. Réseau de connaîssances rigoureux, cohérent et manipulable.


**Commentaires personnels**: 

- Cette approche regroupe plusieurs questionnements que nous avons eu au dernier cours à savoir la pérennité des connaissances dans la base de connaissances. Aucune mention cependant à date d'un paradigme de programmation tel qu'Orienté Objet que nous avons beaucoup discuté avec l'approche par schémas.
- Les schémas pourraient être la fondation d'un tel système, lorsqu'on utilise l'appariement.
- Les schémas ont aussi une mécanique pour la gestion des valeurs manquantes ou imprécises qui n'a pas été introduite jusqu'a maintenant.
- Le fait que certaines parties peuvent être laissées à un traitement manuel démontre à quel point ce type de développement peut être couteux et exigeant ?

#### Application

Le système est composé de deux applications et d'un système de connaissances:

- Éditeur de stratégies de REC: Permet d'éditer la stratégie de remise en change du réseau
- Assistant de planification: obtient la liste des équipements non disponibles des composantes de l'entreprise





