---
header-includes:
  - \usepackage[T1]{fontenc}
  - \usepackage[french]{babel}
  - \usepackage{datetime}
  - \usepackage{hyperref}
---
# Semaine 10: Les tuteurs intelligents

## Etienne Wenger - Artificial intelligence and tutoring systems

Dans le années 80, il y a eu plusieurs tentatives infructueuses à implanter des systèmes intelligents dans un contexte d'éducation.

- Mauvaise qualité du contenu éducatif à intégrer aux systèmes
- Systèmes trop simplistes qui ne répondaient pas aux attentes

Trois sections au livre:

1. Introduction au domaine
    - Unicité de la recherche et méthodologie dans ce domaine
    - Composantes générales des systèmes de tuteurs intelligents, en terme de communication
1. Survol technique des premiers systèmes depuis le début des années 1970
1. Enjeux et thèmes conceptuels. Principes émergents et questions ouvertes.

### Système de communication de connaissances

Contenu tiré du chapitre 1

1. Enseignement assisté par ordinateur: 
    - Approche de système expert où on insère la connaîssance experte de l'enseignant en décisions pédagogiques. 
    - Langages d'édition pour faciliter l'écriture de logiciels éducatifs.
    - Peuvent générer des exercices
    - Adapter le niveau de difficulté à la performance de l'étudiant
1. Tuteur intelligent
    - Transférer l'expertise et non les décisions
    - Moins bonne improvisation, mais meilleure utilisation de l'information disponible
    - Ambitions: 
        - Niveau de communication approprié
        - Rappel de l'information pertinente
        - Expliquer les points difficiles plus en profondeur
        - Sauter les parties vraisemblablement connues de l'étudiant

#### Définition

Communication des connaissances: 

Habileté à causer ou supporter l'acquisition de connaissance d'un individu à un autre via un ensemble restreint d'opérations de communications.

### Implications

Un changement de la programmation des décisions vers la programmation des connaissances. Trois modèles:

- Modèle du domaine
- Modèle de l'étudiant
- Modèle du processus de communication

La tâche intelligente que l'on cherche à reproduire est l'enseignement, ou le transfert de connaissances.

Plusieurs domaines sont impliqués:

- Linguistique
- Anthropologie
- Intéraction humain-machine

## Considérations de base

Contenu tiré du chapitre 2

### Connaissance du domaine: l'objet de la communication (2.1)

Le module expert:

- Traditionnellement, la connaissance est représentée sous forme de frames.
- Deux rôles: source de connaissances et référence pour l'évaluation de l'étudiant. Pouvoir **générer des problèmes et des solutions**, ainsi que tous les chemins de solution possibles, lorsqu'il y en a plusieurs. Optionnel: mesurer le progrès de l'étudiant.

La communicabilité:

- Mesure de la difficulté relative du contenu
- Transparence du raisonnement: de la boite noire à la boite de verre
- Le choix du langage de représentation est un biais dans l'ensemble de la présentation

### L'étudiant: le récepteur de la communication (2.2)

Modèle de l'étudiant:

- Connaissances antérieures: formé à partir de la représentation système de l'expertise cible. Représentation de la formation des connaîssances et des erreurs d'apprentissage.
  - Représentation dans le langage du domaine
  - Approche énumérative: lister les erreurs et incompréhensions à l'aide d'enseignants experts ou dérivées empiriquement. Activité importante pour les concepteurs.
  - **Langage descriptif** pour inclure d'autres caractéristiques de l'étudiant non liées au domaine.
- Comportement d'apprentissage
    - Notes numériques: statistiques de base
    - Diagnostic détaillé: recherche de structure pour l'atteinte du but
      - Perturbation d'un modèle existant: approche à base de cas
      - Apprentissage d'un modèle à partir des données : **apprentissage automatique**
    - Contrainte liée au fait que l'application doit être interactive
    - Sources de bruit dans les données: l'étudiant peut être chanceux dans un test à choix de réponses.
    - Traitement du langage naturel pour avoir une bonne interaction avec l'étudiant

### Connaissance pédagogique: la compétence de communication (2.3)

- Beaucoup de connaissance se trouve imbriquée dans les schémas de connaissances des systèmes d'assistance à l'enseignement. 
- Dans les systèmes de tuteurs intelligents, cette connaissance pédagogique se trouve dans un module séparé.
- Compromis entre laisser l'étudiant trop chercher où être trop présent dans son apprentissage. **Possibilité d'optimisation de cette décision.**

### Interface: la forme de la communication (2.4)

- Présentation finale de la connaissance, décisif dans le processus d'acquisition. 
- Des interfaces de plus en plus sophistiquées deviennent le moteur de la conception de systèmes.
- **Traitement du langage naturel**. 
- Utilisation de langage pseudo-naturel. 
- La granularité des éléments de connaissances est déterminante dans la flexibilité de l'interface.
- La manifestation d'une sorte d'intelligence va mener à des attentes irréalistes de l'utilisateur.

## Réseaux sémantiques et modèles mentaux

### SCHOLAR

- Conçu par Carbonell en 1970
- Prévoir les interaction inattendues: les solutions qui n'ont pas été envisagées et les différentes questions que se posent l'étudiant,
- Questions et réponses sous forme de dialogue d'initiative mixte alimenté par une traversée de graphe
- Sujet: Géographie de l'Amérique du Sud
- Identification de la pertinence des noeuds par des étiquettes numériques. Appariement des réponses par mots-clés.
- Le système ne sait pas comment traiter une mauvaise réponse.
- Limite des réseaux sémantiques: représenter la connaissance procédurale.
- Techniques de raisonnement de base
    - Contradiction
    - Hypothèse
- Éléments manquants:
    - Incertitude
    - Analyse fonctionnelle
- Approche socratique
    - Notion d'insuffisance. Vérifier la véracité d'un fait plus général.
    - Environ 24 règles selon Collins (1977)
    - Étendu à 60 règles dans Collins and Stevens (1982) dans le système WHY.






