---
header-includes:
  - \usepackage[T1]{fontenc}
  - \usepackage[french]{babel}
  - \usepackage{datetime}
  - \usepackage{hyperref}
---
# Semaine 11: Les étapes de la conception des systèmes à base de connaissances

## Première lecture

Source: Studer, R., Benjamins, V.R. and Fensel, D., 1998. Knowledge engineering: principles and methods. Data & knowledge engineering, 25(1-2), pp.161-197.

### Introduction

Parcours historique similaire à la naissance du génie logiciel, l'ingénierie des connaissances est née du besoin d'avoir une base théorique pour la mise en production de logiciels dans l'entreprise.

Développements de la fin des années 1980:

- Méthodes avec limitation des rôles
- Tâches génériques

Trois méthodologies développées dans les dernières années:

- CommonKADS
- MIKE
- Protege-II

### Historique

Processus de transfert: on considère que la connaîssance nécessaire pour résoudre le problème existe déjà et qu'il suffit de la recueillir et de l'implémenter.

Transfert vers l'approche de modélisation: représentation limitée des connaîssances sous forme de règles. Connaissances tacites de l'expert. Difficulté à maintenir les systèmes experts.

Caractéristiques de l'approche de modélisation:

- Approximation de la réalité
- Processus cyclique
- Revisable à chaque étape du processus de modélisation

#### Clancey: Méthodes de résolution de problèmes (PSMs)

- Actions d'inférence
- Séquence d'activation de ces actions
- Rôles de connaissance: utilisation des connaissances dans chacune des actions. Terminologie indépendante du domaine
- Systèmes experts: Classification heuristique
- Autres méthodes:
  - Couverture et différentiation
  - Proposer et reviser

#### Méthodes avec limitation des rôles (RLM)

- Implémentation d'une méthode de résolution de problème en particulier.
- Définit la représentation des connaissances utilisée
- L'expert associe un concept spécifique à chacun des rôles
- Il est facile de concevoir une interface pour alimenter les faits nécessaires.

SALT: méthode *proposer et reviser*

Caractéristiques (rôles génériques):

- Extensionner une conception partielle en proposant des valeurs pour les paramètres qui n'ont pas encore été calculés
- Vérifier si tous les paramètres proposés répondent aux contraintes
- Appliquer des réparations pour enlever les contraintes qui ne sont pas respectées

Méthodes avec limitation des rôles configurables: diviser le problèmes à résoudre en sous-problèmes ayant chacun possiblement leur propre méthode de résolution

#### Tâches génériques

Caractéristiques d'une tâche générique:

- Description générique des ses entrées et sorties
- Schéma fixe de types de connaissances spécifiant la structure de la connaissance du domaine nécessaire pour résoudre une tâche
- Une méthode de résolution de problèmes fixée, précisant les étapes et leur séquence d'application

Un système à base de connaissances est constitué de plusieurs blocs représentant chacun une tâche générique.

Désavantages:

- La tâche est contrainte par sa méthode de résolution de problèmes
- La complexité des tâches est très variable, et aucun niveau de granularité des blocs n'est précisée.

#### Structure de tâches

Basée sur la connaissance des désavantages des tâches génériques. Différencie la tâche de la méthode. Il peut y avoir plusieurs méthodes possibles pour résoudre la même tâches.

Essentiellement, il y a une décomposition à trois niveaux:

- Tâches
- Méthodes de résolution de problèmes
- Sous-tâches

### Cadre de modélisation

#### CommonKADS

Objectif: Préserver les processus d'affaires et la structure actuelle de l'organisation

Un modèle différent par aspect du systèmes à base de connaissances à développer

Aspects fonctionnels

- Organisation:
  - Fonctions de chaque unité de l'organisation
  - Problèmes des processus d'affaires actuels
  - Opportunités liées à l'introduction d'un système à base de connaissances
- Tâche
  - Description hiérarchique des tâches accomplies par l'unité organisationnelle où le système sera implanté
- Agent
  - Compétences requises par tous les agents qui effectuent les tâches manuelles qui seront remplacées par le système à base de connaissances. Ces agents peuvent être des humains, des systèmes mécaniques ou des systèmes informatiques
- Communication
  - Interactions entre les agents: type d'information et initialisation de la communication


Aspects non-fonctionnels

- Expertise
  - Inventaire des différents types de connaissances nécessaires pour résoudre la tâche
  - Trois couches:
    - Tâche: Décomposition en sous-tâches, Description des objectifs
    - Inférence: Processus de raisonnement, Structure d'inférence
    - Domaine: Ontologie, Théorie déclarative
  - Langages:
    - [CML](https://ris.utwente.nl/ws/portalfiles/portal/5475135)
    - [(ML)2](http://www.cs.vu.nl/~frankh/postscript/ECAI92.pdf)
- Conception
  - Architecture du système
  - Mécanismes de calcul

![Le langage CML dans la méthodologie KADS](images/semaine11/kads-cml.png)

#### MIKE

Objectif: Tracabilité de toutes les étapes de développement

Approche basée sur l'intégration avec les méthodes de génie logiciel

Activités:

- Élicitation
  - Entrevues avec les experts
  - Protocoles de connaissances
- Interprétation
  - Modèle structurel (semi-formel)
  - Base de communication entre l'expert et le modélisateur
- Formalisation
  - [Knowledge Acquisition and Representation Language (KARL)](https://pdfs.semanticscholar.org/e2f6/907b93095f6fead9d4d2332557780fe4ba2d.pdf)
- Conception
  - Efficacité et maintenance
  - Contraintes logicielles et matérielles
  - Langage DesignKARL
- Implémentation

![Le langage KARL dans la méthodologie MIKE](images/semaine11/karl.png)

Modèle en spirale: Chaque cycle produit un prototype qui peut être évalué dans un environnement cible.

#### PROTÉGÉ-II

Objectifs: Réutilisation de méthodes de résolution de problèmes et d'ontologies. Outils personnalisés d'acquisition de connaissances par l'utilisation d'outils basés sur des ontologies.

Utilisation d'une ontologie d'application pour étendre les ontologies de domaine avec des concepts et relations spécifiques aux méthodes de résolution de problèmes.

![Ontologies dans Protégé II](images/semaine11/ontologies-protegeii.png)